==> haskell-exceptions-0.10.0-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-exceptions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: exceptions
version: 0.10.0
id: exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf
key: exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf
license: BSD-3-Clause
copyright: Copyright (C) 2013-2015 Edward A. Kmett
           Copyright (C) 2012 Google Inc.
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/exceptions/
synopsis: Extensible optionally-pure exceptions
description:
    Extensible optionally-pure exceptions.
category: Control, Exceptions, Monad
abi: 7910067871295cb7f4f6699a852863a6
exposed: True
exposed-modules:
    Control.Monad.Catch Control.Monad.Catch.Pure
import-dirs: /usr/lib/ghc-8.4.3/site-local/exceptions-0.10.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/exceptions-0.10.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/exceptions-0.10.0
hs-libraries: HSexceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf
depends:
    base-4.11.1.0 stm-2.4.5.0 template-haskell-2.13.0.0
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W mtl-2.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
haddock-interfaces: /usr/share/doc/haskell-exceptions/html/exceptions.haddock
haddock-html: /usr/share/doc/haskell-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-exceptions-0.10.0-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-exceptions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: exceptions
version: 0.10.0
id: exceptions-0.10.0-KqLFUMgISLoDmBqq0VbkGc
key: exceptions-0.10.0-KqLFUMgISLoDmBqq0VbkGc
license: BSD-3-Clause
copyright: Copyright (C) 2013-2015 Edward A. Kmett
           Copyright (C) 2012 Google Inc.
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/exceptions/
synopsis: Extensible optionally-pure exceptions
description:
    Extensible optionally-pure exceptions.
category: Control, Exceptions, Monad
abi: 7e2a2010d6645bddac83e90b3cee8839
exposed: True
exposed-modules:
    Control.Monad.Catch Control.Monad.Catch.Pure
import-dirs: /usr/lib/ghc-8.4.3/site-local/exceptions-0.10.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/exceptions-0.10.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/exceptions-0.10.0
hs-libraries: HSexceptions-0.10.0-KqLFUMgISLoDmBqq0VbkGc
depends:
    base-4.11.1.0 stm-2.4.5.0 template-haskell-2.13.0.0
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W mtl-2.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
haddock-interfaces: /usr/share/doc/haskell-exceptions/html/exceptions.haddock
haddock-html: /usr/share/doc/haskell-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
